#include "HX710B.h"
#include <U8g2lib.h>

#ifdef U8X8_HAVE_HW_SPI
#include <SPI.h>
#endif
#ifdef U8X8_HAVE_HW_I2C
#include <Wire.h>+
#endif

#define SERIAL_ENABLED
#define PRESSED_BUTTON(B) (digitalRead(B)==0)

#define OFFSET_BUTTON_PIN  2 // кнопка сброса
const int SCLK  = 3;  //sensor clock pin (sck)
const int DOUT = 4;   //sensor data pin  (out ADC))

HX710B pressure_sensor;
U8G2_SSD1306_128X64_NONAME_F_4W_SW_SPI u8g2(U8G2_R0, /* clock=*/ 5, /* data=*/ 6, /* cs=*/ 9, /* dc=*/ 8, /* reset=*/ 7);

void zero_offset_fix(void);
void tft_out(long raw);

void setup() {
#ifdef SERIAL_ENABLED
  Serial.begin(57600);
#endif 
  pinMode(OFFSET_BUTTON_PIN,INPUT_PULLUP);

  u8g2.begin();
  u8g2.enableUTF8Print();		// enable UTF8 support for the Arduino print() function
  u8g2.setFontDirection(0);
  pressure_sensor.begin(DOUT, SCLK);
  delay(500);
}


void loop() {
  static long time=0;
  long raw;
  if ((millis()-time)>1000){
    time=millis();
    if (pressure_sensor.is_ready()) {
      raw = pressure_sensor.get_value(1);
      tft_out(raw);
  #ifdef SERIAL_ENABLED
      Serial.print("mm W:");    Serial.println(pressure_sensor.raw2mmWtr(raw),0);
      Serial.print("adc:"); Serial.print(raw);
      Serial.print("  Pa:"); Serial.print(pressure_sensor.raw2pascal(raw));
      Serial.print("mm Hg:");   Serial.print(pressure_sensor.raw2mmHg(raw),0);
  #endif    
    } else {
  #ifdef SERIAL_ENABLED
      Serial.println("Pressure sensor not found");
  #endif
      u8g2.clearBuffer();
      u8g2.setCursor(0, 20);
      u8g2.setFont(u8g2_font_unifont_t_cyrillic);    
      u8g2.print("sensor not found");
      u8g2.sendBuffer();
    }
  }

  if (PRESSED_BUTTON(OFFSET_BUTTON_PIN)) {
    zero_offset_fix();
  }
}

void tft_out(long raw){
  const int high_pixels=12; // высота строки в пикселах
  int line=1;
  u8g2.clearBuffer();
  
  // мм.рт.ст-------------
  u8g2.setFont(u8g2_font_ncenB18_tn);
  u8g2.setCursor(0, (++line)*high_pixels);
  u8g2.print(pressure_sensor.raw2mmWtr(raw),0);
  u8g2.setFont(u8g2_font_unifont_t_cyrillic);
  u8g2.print(" мм.вод.ст.");
  // ----------------

  u8g2.setCursor(0, (++line)*high_pixels); // смещаем позицию на высоту строки high_pixels вниз
  // u8g2.print("adc:"); u8g2.print(raw);
  u8g2.setCursor(0, (++line)*high_pixels); // смещаем позицию на высоту строки high_pixels вниз
  // u8g2.print("Pa:"); u8g2.print(pressure_sensor.raw2pascal(raw));
  u8g2.setCursor(0, (++line)*high_pixels); // смещаем позицию на высоту строки high_pixels вниз
  // u8g2.print("мм.рт.ст: ");   u8g2.print(pressure_sensor.raw2mmHg(raw),1);
  
  // мм.вод.ст. -----------
  u8g2.setFont(u8g2_font_ncenB18_tn);
  // u8g2.setFont(u8g2_font_courB24_tn);
  u8g2.print(pressure_sensor.raw2mmHg(raw),1);
  u8g2.setFont(u8g2_font_unifont_t_cyrillic);  
  u8g2.print(" мм.рт.ст.");
  //---------------

  u8g2.sendBuffer();
}

void zero_offset_fix(void){
    u8g2.clearBuffer();
    u8g2.setCursor(0, 20);
    u8g2.setFont(u8g2_font_unifont_t_cyrillic);    
    if (!pressure_sensor.wait_ready_timeout(1000, 20)){
        u8g2.print("sensor not ready");
        u8g2.sendBuffer();
  #ifdef SERIAL_ENABLED
        Serial.println("sensor not ready");
  #endif    
        delay(1000);
        return;
    }
    u8g2.print("OFFSET process");
    u8g2.sendBuffer();
    long raw = pressure_sensor.read_average(64);
    pressure_sensor.set_offset(raw);
#ifdef SERIAL_ENABLED
    Serial.print("offset is:"); Serial.println(raw);
#endif    
    u8g2.clearBuffer();
    u8g2.setCursor(0, 35);
    u8g2.print("offset: "); u8g2.print(raw);
    u8g2.sendBuffer();
    delay(2000);
}
